"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, account_id: str, display_name: str, domain: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a bot for an Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        display_name(str): The bot display name.
        domain(str, optional): The domain of the Amazon Chime Enterprise account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.bot.create(ctx, account_id=value, display_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.bot.create account_id=value, display_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_bot",
        op_kwargs={
            "AccountId": account_id,
            "DisplayName": display_name,
            "Domain": domain,
        },
    )


async def get(hub, ctx, account_id: str, bot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified bot, such as bot email address, bot type, status, and display name.

    Args:
        account_id(str): The Amazon Chime account ID.
        bot_id(str): The bot ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.bot.get(ctx, account_id=value, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.bot.get account_id=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_bot",
        op_kwargs={"AccountId": account_id, "BotId": bot_id},
    )


async def update(hub, ctx, account_id: str, bot_id: str, disabled: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status of the specified bot, such as starting or stopping the bot from running in your Amazon Chime Enterprise account.

    Args:
        account_id(str): The Amazon Chime account ID.
        bot_id(str): The bot ID.
        disabled(bool, optional): When true, stops the specified bot from running in your account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.bot.update(ctx, account_id=value, bot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.bot.update account_id=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_bot",
        op_kwargs={"AccountId": account_id, "BotId": bot_id, "Disabled": disabled},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, group: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the service configuration associated with the specified resource group. For details about the service configuration syntax, see Service configurations for resource groups.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:GetGroupConfiguration

    Args:
        group(str, optional): The name or the ARN of the resource group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="get_group_configuration",
        op_kwargs={"Group": group},
    )


async def put(hub, ctx, group: str = None, configuration: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a service configuration to the specified group. This occurs asynchronously, and can take time to complete. You can use GetGroupConfiguration to check the status of the update.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:PutGroupConfiguration

    Args:
        group(str, optional): The name or ARN of the resource group with the configuration that you want to update. Defaults to None.
        configuration(List, optional): The new configuration to associate with the specified group. A configuration associates the resource group with an AWS service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements. For information about the syntax of a service configuration, see Service configurations for resource groups.  A resource group can contain either a Configuration or a ResourceQuery, but not both. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.group.configuration.put(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.group.configuration.put
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="put_group_configuration",
        op_kwargs={"Group": group, "Configuration": configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str,
    event_data: str,
    event_time: str,
    event_type: str,
    incident_record_arn: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a custom timeline event on the incident details page of an incident record. Timeline events are automatically created by Incident Manager, marking key moment during an incident. You can create custom timeline events to mark important events that are automatically detected by Incident Manager.

    Args:
        client_token(str): A token ensuring that the action is called only once with the specified details.
        event_data(str): A short description of the event.
        event_time(str): The time that the event occurred.
        event_type(str): The type of the event. You can create timeline events of type Custom Event.
        incident_record_arn(str): The Amazon Resource Name (ARN) of the incident record you are adding the event to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.timeline_event.create(
                ctx,
                client_token=value,
                event_data=value,
                event_time=value,
                event_type=value,
                incident_record_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.timeline_event.create client_token=value, event_data=value, event_time=value, event_type=value, incident_record_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="create_timeline_event",
        op_kwargs={
            "clientToken": client_token,
            "eventData": event_data,
            "eventTime": event_time,
            "eventType": event_type,
            "incidentRecordArn": incident_record_arn,
        },
    )


async def delete(hub, ctx, event_id: str, incident_record_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a timeline event from an incident.

    Args:
        event_id(str): The ID of the event you are updating. You can find this by using ListTimelineEvents.
        incident_record_arn(str): The Amazon Resource Name (ARN) of the incident that the event is part of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.timeline_event.delete(
                ctx, event_id=value, incident_record_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.timeline_event.delete event_id=value, incident_record_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="delete_timeline_event",
        op_kwargs={"eventId": event_id, "incidentRecordArn": incident_record_arn},
    )


async def get(hub, ctx, event_id: str, incident_record_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a timeline event based on its ID and incident record.

    Args:
        event_id(str): The ID of the event. You can get an event's ID when you create it or by using ListTimelineEvents.
        incident_record_arn(str): The Amazon Resource Name (ARN) of the incident that the timeline event is part of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.timeline_event.get(
                ctx, event_id=value, incident_record_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.timeline_event.get event_id=value, incident_record_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="get_timeline_event",
        op_kwargs={"eventId": event_id, "incidentRecordArn": incident_record_arn},
    )


async def list_all(
    hub,
    ctx,
    incident_record_arn: str,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists timeline events of the specified incident record.

    Args:
        filters(List, optional): Filters the timeline events based on the provided conditional values. You can filter timeline events using the following keys:    eventTime     eventType   . Defaults to None.
        incident_record_arn(str): The Amazon Resource Name (ARN) of the incident that the event is part of.
        max_results(int, optional): The maximum number of results per page. Defaults to None.
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.
        sort_by(str, optional): Sort by the specified key value pair. Defaults to None.
        sort_order(str, optional): Sorts the order of timeline events by the value specified in the sortBy field. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.timeline_event.list_all(
                ctx, incident_record_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.timeline_event.list_all incident_record_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="list_timeline_events",
        op_kwargs={
            "filters": filters,
            "incidentRecordArn": incident_record_arn,
            "maxResults": max_results,
            "nextToken": next_token,
            "sortBy": sort_by,
            "sortOrder": sort_order,
        },
    )


async def update(
    hub,
    ctx,
    client_token: str,
    event_id: str,
    incident_record_arn: str,
    event_data: str = None,
    event_time: str = None,
    event_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a timeline event. You can update events of type Custom Event.

    Args:
        client_token(str): A token ensuring that the action is called only once with the specified details.
        event_data(str, optional): A short description of the event. Defaults to None.
        event_id(str): The ID of the event you are updating. You can find this by using ListTimelineEvents.
        event_time(str, optional): The time that the event occurred. Defaults to None.
        event_type(str, optional): The type of the event. You can update events of type Custom Event. Defaults to None.
        incident_record_arn(str): The Amazon Resource Name (ARN) of the incident that the timeline event is part of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_incident.timeline_event.update(
                ctx, client_token=value, event_id=value, incident_record_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_incident.timeline_event.update client_token=value, event_id=value, incident_record_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-incidents",
        operation="update_timeline_event",
        op_kwargs={
            "clientToken": client_token,
            "eventData": event_data,
            "eventId": event_id,
            "eventTime": event_time,
            "eventType": event_type,
            "incidentRecordArn": incident_record_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    user_pool_id: str,
    provider_name: str,
    provider_type: str,
    provider_details: Dict,
    attribute_mapping: Dict = None,
    idp_identifiers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an identity provider for a user pool.

    Args:
        user_pool_id(str): The user pool ID.
        provider_name(str): The identity provider name.
        provider_type(str): The identity provider type.
        provider_details(Dict): The identity provider details. The following list describes the provider detail keys for each identity provider type.   For Google and Login with Amazon:   client_id   client_secret   authorize_scopes     For Facebook:   client_id   client_secret   authorize_scopes   api_version     For Sign in with Apple:   client_id   team_id   key_id   private_key   authorize_scopes     For OIDC providers:   client_id   client_secret   attributes_request_method   oidc_issuer   authorize_scopes   authorize_url if not available from discovery URL specified by oidc_issuer key    token_url if not available from discovery URL specified by oidc_issuer key    attributes_url if not available from discovery URL specified by oidc_issuer key    jwks_uri if not available from discovery URL specified by oidc_issuer key      For SAML providers:   MetadataFile OR MetadataURL   IDPSignout optional     .
        attribute_mapping(Dict, optional): A mapping of identity provider attributes to standard and custom user pool attributes. Defaults to None.
        idp_identifiers(List, optional): A list of identity provider identifiers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.identity_provider.init.create(
                ctx,
                user_pool_id=value,
                provider_name=value,
                provider_type=value,
                provider_details=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.identity_provider.init.create user_pool_id=value, provider_name=value, provider_type=value, provider_details=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="create_identity_provider",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ProviderName": provider_name,
            "ProviderType": provider_type,
            "ProviderDetails": provider_details,
            "AttributeMapping": attribute_mapping,
            "IdpIdentifiers": idp_identifiers,
        },
    )


async def delete(hub, ctx, user_pool_id: str, provider_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an identity provider for a user pool.

    Args:
        user_pool_id(str): The user pool ID.
        provider_name(str): The identity provider name.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.identity_provider.init.delete(
                ctx, user_pool_id=value, provider_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.identity_provider.init.delete user_pool_id=value, provider_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="delete_identity_provider",
        op_kwargs={"UserPoolId": user_pool_id, "ProviderName": provider_name},
    )


async def describe(hub, ctx, user_pool_id: str, provider_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specific identity provider.

    Args:
        user_pool_id(str): The user pool ID.
        provider_name(str): The identity provider name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.identity_provider.init.describe(
                ctx, user_pool_id=value, provider_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.identity_provider.init.describe user_pool_id=value, provider_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="describe_identity_provider",
        op_kwargs={"UserPoolId": user_pool_id, "ProviderName": provider_name},
    )


async def list_all(
    hub, ctx, user_pool_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about all identity providers for a user pool.

    Args:
        user_pool_id(str): The user pool ID.
        max_results(int, optional): The maximum number of identity providers to return. Defaults to None.
        next_token(str, optional): A pagination token. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.identity_provider.init.list_all(
                ctx, user_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.identity_provider.init.list_all user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="list_identity_providers",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    user_pool_id: str,
    provider_name: str,
    provider_details: Dict = None,
    attribute_mapping: Dict = None,
    idp_identifiers: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates identity provider information for a user pool.

    Args:
        user_pool_id(str): The user pool ID.
        provider_name(str): The identity provider name.
        provider_details(Dict, optional): The identity provider details to be updated, such as MetadataURL and MetadataFile. Defaults to None.
        attribute_mapping(Dict, optional): The identity provider attribute mapping to be changed. Defaults to None.
        idp_identifiers(List, optional): A list of identity provider identifiers. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.identity_provider.init.update(
                ctx, user_pool_id=value, provider_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.identity_provider.init.update user_pool_id=value, provider_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="update_identity_provider",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "ProviderName": provider_name,
            "ProviderDetails": provider_details,
            "AttributeMapping": attribute_mapping,
            "IdpIdentifiers": idp_identifiers,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    load_balancer_name: str,
    metric_name: str,
    period: int,
    start_time: str,
    end_time: str,
    unit: str,
    statistics: List,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about health metrics for your Lightsail load balancer. Metrics report the utilization of your resources, and the error counts generated by them. Monitor and collect metric data regularly to maintain the reliability, availability, and performance of your resources.

    Args:
        load_balancer_name(str): The name of the load balancer.
        metric_name(str): The metric for which you want to return information. Valid load balancer metric names are listed below, along with the most useful statistics to include in your request, and the published unit value.     ClientTLSNegotiationErrorCount  - The number of TLS connections initiated by the client that did not establish a session with the load balancer due to a TLS error generated by the load balancer. Possible causes include a mismatch of ciphers or protocols.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.     HealthyHostCount  - The number of target instances that are considered healthy.  Statistics: The most useful statistic are Average, Minimum, and Maximum.  Unit: The published unit is Count.     HTTPCode_Instance_2XX_Count  - The number of HTTP 2XX response codes generated by the target instances. This does not include any response codes generated by the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     HTTPCode_Instance_3XX_Count  - The number of HTTP 3XX response codes generated by the target instances. This does not include any response codes generated by the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     HTTPCode_Instance_4XX_Count  - The number of HTTP 4XX response codes generated by the target instances. This does not include any response codes generated by the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     HTTPCode_Instance_5XX_Count  - The number of HTTP 5XX response codes generated by the target instances. This does not include any response codes generated by the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     HTTPCode_LB_4XX_Count  - The number of HTTP 4XX client error codes that originated from the load balancer. Client errors are generated when requests are malformed or incomplete. These requests were not received by the target instance. This count does not include response codes generated by the target instances.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     HTTPCode_LB_5XX_Count  - The number of HTTP 5XX server error codes that originated from the load balancer. This does not include any response codes generated by the target instance. This metric is reported if there are no healthy instances attached to the load balancer, or if the request rate exceeds the capacity of the instances (spillover) or the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     InstanceResponseTime  - The time elapsed, in seconds, after the request leaves the load balancer until a response from the target instance is received.  Statistics: The most useful statistic is Average.  Unit: The published unit is Seconds.     RejectedConnectionCount  - The number of connections that were rejected because the load balancer had reached its maximum number of connections.  Statistics: The most useful statistic is Sum.  Unit: The published unit is Count.     RequestCount  - The number of requests processed over IPv4. This count includes only the requests with a response generated by a target instance of the load balancer.  Statistics: The most useful statistic is Sum. Note that Minimum, Maximum, and Average all return 1.  Unit: The published unit is Count.     UnhealthyHostCount  - The number of target instances that are considered unhealthy.  Statistics: The most useful statistic are Average, Minimum, and Maximum.  Unit: The published unit is Count.  .
        period(int): The granularity, in seconds, of the returned data points.
        start_time(str): The start time of the period.
        end_time(str): The end time of the period.
        unit(str): The unit for the metric data request. Valid units depend on the metric data being requested. For the valid units with each available metric, see the metricName parameter.
        statistics(List): The statistic for the metric. The following statistics are available:    Minimum - The lowest value observed during the specified period. Use this value to determine low volumes of activity for your application.    Maximum - The highest value observed during the specified period. Use this value to determine high volumes of activity for your application.    Sum - All values submitted for the matching metric added together. You can use this statistic to determine the total volume of a metric.    Average - The value of Sum / SampleCount during the specified period. By comparing this statistic with the Minimum and Maximum values, you can determine the full scope of a metric and how close the average use is to the Minimum and Maximum values. This comparison helps you to know when to increase or decrease your resources.    SampleCount - The count, or number, of data points used for the statistical calculation.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.metric_data.get(
                ctx,
                load_balancer_name=value,
                metric_name=value,
                period=value,
                start_time=value,
                end_time=value,
                unit=value,
                statistics=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.metric_data.get load_balancer_name=value, metric_name=value, period=value, start_time=value, end_time=value, unit=value, statistics=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_load_balancer_metric_data",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "metricName": metric_name,
            "period": period,
            "startTime": start_time,
            "endTime": end_time,
            "unit": unit,
            "statistics": statistics,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    expression_type: str,
    expression: str,
    role_arn: str,
    description: str = None,
    tags: List = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new destination that maps a device message to an AWS IoT rule.

    Args:
        name(str): The name of the new resource.
        expression_type(str): The type of value in Expression.
        expression(str): The rule name or topic rule to send messages to.
        description(str, optional): The description of the new resource. Defaults to None.
        role_arn(str): The ARN of the IAM Role that authorizes the destination.
        tags(List, optional): The tags to attach to the new destination. Tags are metadata that you can use to manage a resource. Defaults to None.
        client_request_token(str, optional): Each resource must have a unique client request token. If you try to create a new resource with the same token as a resource that already exists, an exception occurs. If you omit this value, AWS SDKs will automatically generate a unique client request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.destination.create(
                ctx, name=value, expression_type=value, expression=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.destination.create name=value, expression_type=value, expression=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="create_destination",
        op_kwargs={
            "Name": name,
            "ExpressionType": expression_type,
            "Expression": expression,
            "Description": description,
            "RoleArn": role_arn,
            "Tags": tags,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a destination.

    Args:
        name(str): The name of the resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.destination.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.destination.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="delete_destination",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a destination.

    Args:
        name(str): The name of the resource to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.destination.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.destination.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_destination",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the destinations registered to your AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.destination.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.destination.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="list_destinations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    expression_type: str = None,
    expression: str = None,
    description: str = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates properties of a destination.

    Args:
        name(str): The new name of the resource.
        expression_type(str, optional): The type of value in Expression. Defaults to None.
        expression(str, optional): The new rule name or topic rule to send messages to. Defaults to None.
        description(str, optional): A new description of the resource. Defaults to None.
        role_arn(str, optional): The ARN of the IAM Role that authorizes the destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.destination.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.destination.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="update_destination",
        op_kwargs={
            "Name": name,
            "ExpressionType": expression_type,
            "Expression": expression,
            "Description": description,
            "RoleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, destination_configuration: Dict, name: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new recording configuration, used to enable recording to Amazon S3.  Known issue: In the us-east-1 region, if you use the AWS CLI to create a recording configuration, it returns success even if the S3 bucket is in a different region. In this case, the state of the recording configuration is CREATE_FAILED (instead of ACTIVE). (In other regions, the CLI correctly returns failure if the bucket is in a different region.)  Workaround: Ensure that your S3 bucket is in the same region as the recording configuration. If you create a recording configuration in a different region as your S3 bucket, delete that recording configuration and create a new one with an S3 bucket from the correct region.

    Args:
        name(str, optional): An arbitrary string (a nickname) that helps the customer identify that resource. The value does not need to be unique. Defaults to None.
        destination_configuration(Dict): A complex type that contains a destination configuration for where recorded video will be stored.
        tags(Dict, optional): Array of 1-50 maps, each of the form string:string (key:value). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.recording_configuration.create(
                ctx, destination_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.recording_configuration.create destination_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="create_recording_configuration",
        op_kwargs={
            "name": name,
            "destinationConfiguration": destination_configuration,
            "tags": tags,
        },
    )


async def delete(hub, ctx, arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the recording configuration for the specified ARN. If you try to delete a recording configuration that is associated with a channel, you will get an error (409 ConflictException). To avoid this, for all channels that reference the recording configuration, first use UpdateChannel to set the recordingConfigurationArn field to an empty string, then use DeleteRecordingConfiguration.

    Args:
        arn(str): ARN of the recording configuration to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.recording_configuration.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.recording_configuration.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="delete_recording_configuration",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the recording configuration for the specified ARN.

    Args:
        arn(str): ARN of the recording configuration to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.recording_configuration.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.recording_configuration.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="get_recording_configuration",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about all recording configurations in your account, in the AWS region where the API request is processed.

    Args:
        next_token(str, optional): The first recording configuration to retrieve. This is used for pagination; see the nextToken response field. Defaults to None.
        max_results(int, optional): Maximum number of recording configurations to return. Default: 50. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.recording_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.recording_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="list_recording_configurations",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, trail_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the settings for the event selectors that you configured for your trail. The information returned for your event selectors includes the following:   If your event selector includes read-only events, write-only events, or all events. This applies to both management events and data events.   If your event selector includes management events.   If your event selector includes data events, the resources on which you are logging data events.   For more information, see Logging Data and Management Events for Trails  in the AWS CloudTrail User Guide.

    Args:
        trail_name(str): Specifies the name of the trail or trail ARN. If you specify a trail name, the string must meet the following requirements:   Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)   Start with a letter or number, and end with a letter or number   Be between 3 and 128 characters   Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are not valid.   Not be in IP address format (for example, 192.168.5.4)   If you specify a trail ARN, it must be in the format:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.event.selector.get_all(ctx, trail_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.event.selector.get_all trail_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="get_event_selectors",
        op_kwargs={"TrailName": trail_name},
    )


async def put_multiple(
    hub,
    ctx,
    trail_name: str,
    event_selectors: List = None,
    advanced_event_selectors: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Configures an event selector or advanced event selectors for your trail. Use event selectors or advanced event selectors to specify management and data event settings for your trail. By default, trails created without specific event selectors are configured to log all read and write management events, and no data events. When an event occurs in your account, CloudTrail evaluates the event selectors or advanced event selectors in all trails. For each trail, if the event matches any event selector, the trail processes and logs the event. If the event doesn't match any event selector, the trail doesn't log the event.  Example   You create an event selector for a trail and specify that you want write-only events.   The EC2 GetConsoleOutput and RunInstances API operations occur in your account.   CloudTrail evaluates whether the events match your event selectors.   The RunInstances is a write-only event and it matches your event selector. The trail logs the event.   The GetConsoleOutput is a read-only event that doesn't match your event selector. The trail doesn't log the event.    The PutEventSelectors operation must be called from the region in which the trail was created; otherwise, an InvalidHomeRegionException exception is thrown. You can configure up to five event selectors for each trail. For more information, see Logging data and management events for trails  and Quotas in AWS CloudTrail in the AWS CloudTrail User Guide. You can add advanced event selectors, and conditions for your advanced event selectors, up to a maximum of 500 values for all conditions and selectors on a trail. You can use either AdvancedEventSelectors or EventSelectors, but not both. If you apply AdvancedEventSelectors to a trail, any existing EventSelectors are overwritten. For more information about advanced event selectors, see Logging data events for trails in the AWS CloudTrail User Guide.

    Args:
        trail_name(str): Specifies the name of the trail or trail ARN. If you specify a trail name, the string must meet the following requirements:   Contain only ASCII letters (a-z, A-Z), numbers (0-9), periods (.), underscores (_), or dashes (-)   Start with a letter or number, and end with a letter or number   Be between 3 and 128 characters   Have no adjacent periods, underscores or dashes. Names like my-_namespace and my--namespace are invalid.   Not be in IP address format (for example, 192.168.5.4)   If you specify a trail ARN, it must be in the format:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .
        event_selectors(List, optional): Specifies the settings for your event selectors. You can configure up to five event selectors for a trail. You can use either EventSelectors or AdvancedEventSelectors in a PutEventSelectors request, but not both. If you apply EventSelectors to a trail, any existing AdvancedEventSelectors are overwritten. Defaults to None.
        advanced_event_selectors(List, optional):  Specifies the settings for advanced event selectors. You can add advanced event selectors, and conditions for your advanced event selectors, up to a maximum of 500 values for all conditions and selectors on a trail. You can use either AdvancedEventSelectors or EventSelectors, but not both. If you apply AdvancedEventSelectors to a trail, any existing EventSelectors are overwritten. For more information about advanced event selectors, see Logging data events for trails in the AWS CloudTrail User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.event.selector.put_multiple(ctx, trail_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.event.selector.put_multiple trail_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="put_event_selectors",
        op_kwargs={
            "TrailName": trail_name,
            "EventSelectors": event_selectors,
            "AdvancedEventSelectors": advanced_event_selectors,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    pricing_plan: str = None,
    reservation_plan_settings: Dict = None,
    status: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new transcoding queue. For information about queues, see Working With Queues in the User Guide at https://docs.aws.amazon.com/mediaconvert/latest/ug/working-with-queues.html

    Args:
        description(str, optional): Optional. A description of the queue that you are creating. Defaults to None.
        name(str): The name of the queue that you are creating.
        pricing_plan(str, optional): Specifies whether the pricing plan for the queue is on-demand or reserved. For on-demand, you pay per minute, billed in increments of .01 minute. For reserved, you pay for the transcoding capacity of the entire queue, regardless of how much or how little you use it. Reserved pricing requires a 12-month commitment. When you use the API to create a queue, the default is on-demand. Defaults to None.
        reservation_plan_settings(Dict, optional): Details about the pricing plan for your reserved queue. Required for reserved queues and not applicable to on-demand queues. Defaults to None.
        status(str, optional): Initial state of the queue. If you create a paused queue, then jobs in that queue won't begin. Defaults to None.
        tags(Dict, optional): The tags that you want to add to the resource. You can tag resources with a key-value pair or with only a key. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.queue.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.queue.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="create_queue",
        op_kwargs={
            "Description": description,
            "Name": name,
            "PricingPlan": pricing_plan,
            "ReservationPlanSettings": reservation_plan_settings,
            "Status": status,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Permanently delete a queue you have created.

    Args:
        name(str): The name of the queue that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.queue.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.queue.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="delete_queue",
        op_kwargs={"Name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve the JSON for a specific queue.

    Args:
        name(str): The name of the queue that you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.queue.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.queue.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="get_queue",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub,
    ctx,
    list_by: str = None,
    max_results: int = None,
    next_token: str = None,
    order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a JSON array of up to twenty of your queues. This will return the queues themselves, not just a list of them. To retrieve the next twenty queues, use the nextToken string returned with the array.

    Args:
        list_by(str, optional): Optional. When you request a list of queues, you can choose to list them alphabetically by NAME or chronologically by CREATION_DATE. If you don't specify, the service will list them by creation date. Defaults to None.
        max_results(int, optional): Optional. Number of queues, up to twenty, that will be returned at one time. Defaults to None.
        next_token(str, optional): Use this string, provided with the response to a previous request, to request the next batch of queues. Defaults to None.
        order(str, optional): Optional. When you request lists of resources, you can specify whether they are sorted in ASCENDING or DESCENDING order. Default varies by resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.queue.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.queue.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="list_queues",
        op_kwargs={
            "ListBy": list_by,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Order": order,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    reservation_plan_settings: Dict = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify one of your existing queues.

    Args:
        description(str, optional): The new description for the queue, if you are changing it. Defaults to None.
        name(str): The name of the queue that you are modifying.
        reservation_plan_settings(Dict, optional): The new details of your pricing plan for your reserved queue. When you set up a new pricing plan to replace an expired one, you enter into another 12-month commitment. When you add capacity to your queue by increasing the number of RTS, you extend the term of your commitment to 12 months from when you add capacity. After you make these commitments, you can't cancel them. Defaults to None.
        status(str, optional): Pause or activate a queue by changing its status between ACTIVE and PAUSED. If you pause a queue, jobs in that queue won't begin. Jobs that are running when you pause the queue continue to run until they finish or result in an error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconvert.queue.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconvert.queue.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconvert",
        operation="update_queue",
        op_kwargs={
            "Description": description,
            "Name": name,
            "ReservationPlanSettings": reservation_plan_settings,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, queue_url: str) -> Dict:
    r"""
    **Autogenerated function**

    List all cost allocation tags added to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.  Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a user name in the Amazon SQS Developer Guide.

    Args:
        queue_url(str): The URL of the queue.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.queue.tag.list_all(ctx, queue_url=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.queue.tag.list_all queue_url=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="list_queue_tags",
        op_kwargs={"QueueUrl": queue_url},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, role_arn: str = None, kms_key_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty dataset group. A dataset group contains related datasets that supply data for training a model. A dataset group can contain at most three datasets, one for each type of dataset:   Interactions   Items   Users   To train a model (create a solution), a dataset group that contains an Interactions dataset is required. Call CreateDataset to add a dataset to the group. A dataset group can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED   DELETE PENDING   To get the status of the dataset group, call DescribeDatasetGroup. If the status shows as CREATE FAILED, the response includes a failureReason key, which describes why the creation failed.  You must wait until the status of the dataset group is ACTIVE before adding a dataset to the group.  You can specify an Key Management Service (KMS) key to encrypt the datasets in the group. If you specify a KMS key, you must also include an Identity and Access Management (IAM) role that has permission to access the key.  APIs that require a dataset group ARN in the request     CreateDataset     CreateEventTracker     CreateSolution     Related APIs     ListDatasetGroups     DescribeDatasetGroup     DeleteDatasetGroup

    Args:
        name(str): The name for the new dataset group.
        role_arn(str, optional): The ARN of the Identity and Access Management (IAM) role that has permissions to access the Key Management Service (KMS) key. Supplying an IAM role is only valid when also specifying a KMS key. Defaults to None.
        kms_key_arn(str, optional): The Amazon Resource Name (ARN) of a Key Management Service (KMS) key used to encrypt the datasets. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.group.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.group.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_dataset_group",
        op_kwargs={"name": name, "roleArn": role_arn, "kmsKeyArn": kms_key_arn},
    )


async def delete(hub, ctx, dataset_group_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a dataset group. Before you delete a dataset group, you must delete the following:   All associated event trackers.   All associated solutions.   All datasets in the dataset group.

    Args:
        dataset_group_arn(str): The ARN of the dataset group to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.group.delete(ctx, dataset_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.group.delete dataset_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="delete_dataset_group",
        op_kwargs={"datasetGroupArn": dataset_group_arn},
    )


async def describe(hub, ctx, dataset_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the given dataset group. For more information on dataset groups, see CreateDatasetGroup.

    Args:
        dataset_group_arn(str): The Amazon Resource Name (ARN) of the dataset group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.group.describe(ctx, dataset_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.group.describe dataset_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_dataset_group",
        op_kwargs={"datasetGroupArn": dataset_group_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of dataset groups. The response provides the properties for each dataset group, including the Amazon Resource Name (ARN). For more information on dataset groups, see CreateDatasetGroup.

    Args:
        next_token(str, optional): A token returned from the previous call to ListDatasetGroups for getting the next set of dataset groups (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of dataset groups to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.dataset.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.dataset.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_dataset_groups",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def apply(
    hub, ctx, action_id: str, environment_name: str = None, environment_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Applies a scheduled managed action immediately. A managed action can be applied only if its status is Scheduled. Get the status and action ID of a managed action with DescribeEnvironmentManagedActions.

    Args:
        environment_name(str, optional): The name of the target environment. Defaults to None.
        environment_id(str, optional): The environment ID of the target environment. Defaults to None.
        action_id(str): The action ID of the scheduled managed action to execute.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.managed_action.init.apply(
                ctx, action_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.managed_action.init.apply action_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="apply_environment_managed_action",
        op_kwargs={
            "EnvironmentName": environment_name,
            "EnvironmentId": environment_id,
            "ActionId": action_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    environment_name: str = None,
    environment_id: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists an environment's upcoming and in-progress managed actions.

    Args:
        environment_name(str, optional): The name of the target environment. Defaults to None.
        environment_id(str, optional): The environment ID of the target environment. Defaults to None.
        status(str, optional): To show only actions with a particular status, specify a status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.environment.managed_action.init.describe_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.environment.managed_action.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_environment_managed_actions",
        op_kwargs={
            "EnvironmentName": environment_name,
            "EnvironmentId": environment_id,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, routing_control_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of all Amazon Route 53 health checks associated with a specific routing control.

    Args:
        max_results(int, optional): The number of objects that you want to return with this call. Defaults to None.
        next_token(str, optional): The token that identifies which batch of results you want to see. Defaults to None.
        routing_control_arn(str): The Amazon Resource Name (ARN) of the routing control that you're getting details for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53_recovery_control_config.associated_route53_health_check.list_all(
                ctx, routing_control_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53_recovery_control_config.associated_route53_health_check.list_all routing_control_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53-recovery-control-config",
        operation="list_associated_route53_health_checks",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "RoutingControlArn": routing_control_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, deletion_task_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the status of your service-linked role deletion. After you use DeleteServiceLinkedRole to submit a service-linked role for deletion, you can use the DeletionTaskId parameter in GetServiceLinkedRoleDeletionStatus to check the status of the deletion. If the deletion fails, this operation returns the reason that it failed, if that information is returned by the service.

    Args:
        deletion_task_id(str): The deletion task identifier. This identifier is returned by the DeleteServiceLinkedRole operation in the format task/aws-service-role/<service-principal-name>/<role-name>/<task-uuid>.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.linked_role.deletion_status.get(
                ctx, deletion_task_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.linked_role.deletion_status.get deletion_task_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_service_linked_role_deletion_status",
        op_kwargs={"DeletionTaskId": deletion_task_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of all tags for the specified AppStream 2.0 resource. You can tag AppStream 2.0 image builders, images, fleets, and stacks. For more information about tags, see Tagging Your Resources in the Amazon AppStream 2.0 Administration Guide.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="list_tags_for_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "identity_id_format"


async def describe(hub, ctx, principal_arn: str, resource: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the ID format settings for resources for the specified IAM user, IAM role, or root user. For example, you can view the resource types that are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the principal specified in the request. They do not apply to the principal that makes the request.

    Args:
        principal_arn(str): The ARN of the principal, which can be an IAM role, IAM user, or the root user.
        resource(str, optional): The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.identity_id_format_.describe(ctx, principal_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.identity_id_format.describe principal_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_identity_id_format",
        op_kwargs={"PrincipalArn": principal_arn, "Resource": resource},
    )


async def modify(
    hub, ctx, principal_arn: str, resource: str, use_long_ids: bool
) -> None:
    r"""
    **Autogenerated function**

    Modifies the ID format of a resource for a specified IAM user, IAM role, or the root user for an account; or all IAM users, IAM roles, and the root user for an account. You can specify that resources should receive longer IDs (17-character IDs) when they are created.  This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  This setting applies to the principal specified in the request; it does not apply to the principal that makes the request.  Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.

    Args:
        principal_arn(str): The ARN of the principal, which can be an IAM user, IAM role, or the root user. Specify all to modify the ID format for all IAM users, IAM roles, and the root user of the account.
        resource(str): The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. Alternatively, use the all-current option to include all resource types that are currently within their opt-in period for longer IDs.
        use_long_ids(bool): Indicates whether the resource should use longer IDs (17-character IDs).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.identity_id_format_.modify(
                ctx, principal_arn=value, resource=value, use_long_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.identity_id_format.modify principal_arn=value, resource=value, use_long_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_identity_id_format",
        op_kwargs={
            "PrincipalArn": principal_arn,
            "Resource": resource,
            "UseLongIds": use_long_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def authorize(
    hub,
    ctx,
    cluster_security_group_name: str,
    cidrip: str = None,
    ec2_security_group_name: str = None,
    ec2_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an inbound (ingress) rule to an Amazon Redshift security group. Depending on whether the application accessing your cluster is running on the Internet or an Amazon EC2 instance, you can authorize inbound access to either a Classless Interdomain Routing (CIDR)/Internet Protocol (IP) range or to an Amazon EC2 security group. You can add as many as 20 ingress rules to an Amazon Redshift security group. If you authorize access to an Amazon EC2 security group, specify EC2SecurityGroupName and EC2SecurityGroupOwnerId. The Amazon EC2 security group and Amazon Redshift cluster must be in the same Amazon Web Services Region.  If you authorize access to a CIDR/IP address range, specify CIDRIP. For an overview of CIDR blocks, see the Wikipedia article on Classless Inter-Domain Routing.  You must also associate the security group with a cluster so that clients running on these IP addresses or the EC2 instance are authorized to connect to the cluster. For information about managing security groups, go to Working with Security Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_security_group_name(str): The name of the security group to which the ingress rule is added.
        cidrip(str, optional): The IP range to be added the Amazon Redshift security group. Defaults to None.
        ec2_security_group_name(str, optional): The EC2 security group to be added the Amazon Redshift security group. Defaults to None.
        ec2_security_group_owner_id(str, optional): The Amazon Web Services account number of the owner of the security group specified by the EC2SecurityGroupName parameter. The Amazon Web Services Access Key ID is not an acceptable value.  Example: 111122223333 . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.security_group.ingress.authorize(
                ctx, cluster_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.security_group.ingress.authorize cluster_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="authorize_cluster_security_group_ingress",
        op_kwargs={
            "ClusterSecurityGroupName": cluster_security_group_name,
            "CIDRIP": cidrip,
            "EC2SecurityGroupName": ec2_security_group_name,
            "EC2SecurityGroupOwnerId": ec2_security_group_owner_id,
        },
    )


async def revoke(
    hub,
    ctx,
    cluster_security_group_name: str,
    cidrip: str = None,
    ec2_security_group_name: str = None,
    ec2_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Revokes an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group. To add an ingress rule, see AuthorizeClusterSecurityGroupIngress. For information about managing security groups, go to Amazon Redshift Cluster Security Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        cluster_security_group_name(str): The name of the security Group from which to revoke the ingress rule.
        cidrip(str, optional): The IP range for which to revoke access. This range must be a valid Classless Inter-Domain Routing (CIDR) block of IP addresses. If CIDRIP is specified, EC2SecurityGroupName and EC2SecurityGroupOwnerId cannot be provided. . Defaults to None.
        ec2_security_group_name(str, optional): The name of the EC2 Security Group whose access is to be revoked. If EC2SecurityGroupName is specified, EC2SecurityGroupOwnerId must also be provided and CIDRIP cannot be provided. . Defaults to None.
        ec2_security_group_owner_id(str, optional): The Amazon Web Services account number of the owner of the security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID is not an acceptable value. If EC2SecurityGroupOwnerId is specified, EC2SecurityGroupName must also be provided. and CIDRIP cannot be provided.  Example: 111122223333 . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.security_group.ingress.revoke(
                ctx, cluster_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.security_group.ingress.revoke cluster_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="revoke_cluster_security_group_ingress",
        op_kwargs={
            "ClusterSecurityGroupName": cluster_security_group_name,
            "CIDRIP": cidrip,
            "EC2SecurityGroupName": ec2_security_group_name,
            "EC2SecurityGroupOwnerId": ec2_security_group_owner_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub,
    ctx,
    direct_connect_gateway_id: str,
    proposal_id: str,
    associated_gateway_owner_account: str,
    override_allowed_prefixes_to_direct_connect_gateway: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a proposal request to attach a virtual private gateway or transit gateway to a Direct Connect gateway.

    Args:
        direct_connect_gateway_id(str): The ID of the Direct Connect gateway.
        proposal_id(str): The ID of the request proposal.
        associated_gateway_owner_account(str): The ID of the account that owns the virtual private gateway or transit gateway.
        override_allowed_prefixes_to_direct_connect_gateway(List, optional): Overrides the Amazon VPC prefixes advertised to the Direct Connect gateway. For information about how to set the prefixes, see Allowed Prefixes in the Direct Connect User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.proposal.accept(
                ctx,
                direct_connect_gateway_id=value,
                proposal_id=value,
                associated_gateway_owner_account=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.proposal.accept direct_connect_gateway_id=value, proposal_id=value, associated_gateway_owner_account=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="accept_direct_connect_gateway_association_proposal",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "proposalId": proposal_id,
            "associatedGatewayOwnerAccount": associated_gateway_owner_account,
            "overrideAllowedPrefixesToDirectConnectGateway": override_allowed_prefixes_to_direct_connect_gateway,
        },
    )


async def create(
    hub,
    ctx,
    direct_connect_gateway_id: str,
    direct_connect_gateway_owner_account: str,
    gateway_id: str,
    add_allowed_prefixes_to_direct_connect_gateway: List = None,
    remove_allowed_prefixes_to_direct_connect_gateway: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a proposal to associate the specified virtual private gateway or transit gateway with the specified Direct Connect gateway. You can associate a Direct Connect gateway and virtual private gateway or transit gateway that is owned by any account.

    Args:
        direct_connect_gateway_id(str): The ID of the Direct Connect gateway.
        direct_connect_gateway_owner_account(str): The ID of the account that owns the Direct Connect gateway.
        gateway_id(str): The ID of the virtual private gateway or transit gateway.
        add_allowed_prefixes_to_direct_connect_gateway(List, optional): The Amazon VPC prefixes to advertise to the Direct Connect gateway. Defaults to None.
        remove_allowed_prefixes_to_direct_connect_gateway(List, optional): The Amazon VPC prefixes to no longer advertise to the Direct Connect gateway. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.proposal.create(
                ctx,
                direct_connect_gateway_id=value,
                direct_connect_gateway_owner_account=value,
                gateway_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.proposal.create direct_connect_gateway_id=value, direct_connect_gateway_owner_account=value, gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_direct_connect_gateway_association_proposal",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "directConnectGatewayOwnerAccount": direct_connect_gateway_owner_account,
            "gatewayId": gateway_id,
            "addAllowedPrefixesToDirectConnectGateway": add_allowed_prefixes_to_direct_connect_gateway,
            "removeAllowedPrefixesToDirectConnectGateway": remove_allowed_prefixes_to_direct_connect_gateway,
        },
    )


async def delete(hub, ctx, proposal_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway or transit gateway.

    Args:
        proposal_id(str): The ID of the proposal.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.proposal.delete(
                ctx, proposal_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.proposal.delete proposal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_direct_connect_gateway_association_proposal",
        op_kwargs={"proposalId": proposal_id},
    )


async def describe_all(
    hub,
    ctx,
    direct_connect_gateway_id: str = None,
    proposal_id: str = None,
    associated_gateway_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more association proposals for connection between a virtual private gateway or transit gateway and a Direct Connect gateway.

    Args:
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.
        proposal_id(str, optional): The ID of the proposal. Defaults to None.
        associated_gateway_id(str, optional): The ID of the associated gateway. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If MaxResults is given a value larger than 100, only 100 results are returned. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.association.proposal.describe_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.association.proposal.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_direct_connect_gateway_association_proposals",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "proposalId": proposal_id,
            "associatedGatewayId": associated_gateway_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    default_run_properties: Dict = None,
    tags: Dict = None,
    max_concurrent_runs: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new workflow.

    Args:
        name(str): The name to be assigned to the workflow. It should be unique within your account.
        description(str, optional): A description of the workflow. Defaults to None.
        default_run_properties(Dict, optional): A collection of properties to be used as part of each execution of the workflow. Defaults to None.
        tags(Dict, optional): The tags to be used with this workflow. Defaults to None.
        max_concurrent_runs(int, optional): You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_workflow",
        op_kwargs={
            "Name": name,
            "Description": description,
            "DefaultRunProperties": default_run_properties,
            "Tags": tags,
            "MaxConcurrentRuns": max_concurrent_runs,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a workflow.

    Args:
        name(str): Name of the workflow to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="glue", operation="delete_workflow", op_kwargs={"Name": name}
    )


async def get(hub, ctx, name: str, include_graph: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves resource metadata for a workflow.

    Args:
        name(str): The name of the workflow to retrieve.
        include_graph(bool, optional): Specifies whether to include a graph when returning the workflow resource metadata. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_workflow",
        op_kwargs={"Name": name, "IncludeGraph": include_graph},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists names of workflows created in the account.

    Args:
        next_token(str, optional): A continuation token, if this is a continuation request. Defaults to None.
        max_results(int, optional): The maximum size of a list to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="list_workflows",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub,
    ctx,
    name: str,
    description: str = None,
    default_run_properties: Dict = None,
    max_concurrent_runs: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing workflow.

    Args:
        name(str): Name of the workflow to be updated.
        description(str, optional): The description of the workflow. Defaults to None.
        default_run_properties(Dict, optional): A collection of properties to be used as part of each execution of the workflow. Defaults to None.
        max_concurrent_runs(int, optional): You can use this parameter to prevent unwanted multiple updates to data, to control costs, or in some cases, to prevent exceeding the maximum number of concurrent runs of any of the component jobs. If you leave this parameter blank, there is no limit to the number of concurrent workflow runs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.workflow.init.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.workflow.init.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_workflow",
        op_kwargs={
            "Name": name,
            "Description": description,
            "DefaultRunProperties": default_run_properties,
            "MaxConcurrentRuns": max_concurrent_runs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    transit_gateway_attachment_id: str = None,
    subnet_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a request to associate subnets with a transit gateway multicast domain.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        transit_gateway_attachment_id(str, optional): The ID of the transit gateway attachment. Defaults to None.
        subnet_ids(List, optional): The IDs of the subnets to associate with the transit gateway multicast domain. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.association.accept(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.association.accept
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="accept_transit_gateway_multicast_domain_associations",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "SubnetIds": subnet_ids,
            "DryRun": dry_run,
        },
    )


async def get_all(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the associations for the transit gateway multicast domain.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    resource-id - The ID of the resource.    resource-type - The type of resource. The valid value is: vpc.    state - The state of the subnet association. Valid values are associated | associating | disassociated | disassociating.    subnet-id - The ID of the subnet.    transit-gateway-attachment-id - The id of the transit gateway attachment.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.association.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.association.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_transit_gateway_multicast_domain_associations",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def reject(
    hub,
    ctx,
    transit_gateway_multicast_domain_id: str = None,
    transit_gateway_attachment_id: str = None,
    subnet_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Rejects a request to associate cross-account subnets with a transit gateway multicast domain.

    Args:
        transit_gateway_multicast_domain_id(str, optional): The ID of the transit gateway multicast domain. Defaults to None.
        transit_gateway_attachment_id(str, optional): The ID of the transit gateway attachment. Defaults to None.
        subnet_ids(List, optional): The IDs of the subnets to associate with the transit gateway multicast domain. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.multicast.domain.association.reject(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.multicast.domain.association.reject
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reject_transit_gateway_multicast_domain_associations",
        op_kwargs={
            "TransitGatewayMulticastDomainId": transit_gateway_multicast_domain_id,
            "TransitGatewayAttachmentId": transit_gateway_attachment_id,
            "SubnetIds": subnet_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    time_period: Dict,
    group_by: List = None,
    granularity: str = None,
    filter_: Dict = None,
    metrics: List = None,
    next_page_token: str = None,
    sort_by: Dict = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the reservation coverage for your account. This enables you to see how much of your Amazon Elastic Compute Cloud, Amazon ElastiCache, Amazon Relational Database Service, or Amazon Redshift usage is covered by a reservation. An organization's management account can see the coverage of the associated member accounts. This supports dimensions, Cost Categories, and nested expressions. For any time period, you can filter data about reservation usage by the following dimensions:   AZ   CACHE_ENGINE   DATABASE_ENGINE   DEPLOYMENT_OPTION   INSTANCE_TYPE   LINKED_ACCOUNT   OPERATING_SYSTEM   PLATFORM   REGION   SERVICE   TAG   TENANCY   To determine valid values for a dimension, use the GetDimensionValues operation.

    Args:
        time_period(Dict): The start and end dates of the period that you want to retrieve data about reservation coverage for. You can retrieve data for a maximum of 13 months: the last 12 months and the current month. The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01. .
        group_by(List, optional): You can group the data by the following attributes:   AZ   CACHE_ENGINE   DATABASE_ENGINE   DEPLOYMENT_OPTION   INSTANCE_TYPE   LINKED_ACCOUNT   OPERATING_SYSTEM   PLATFORM   REGION   TENANCY  . Defaults to None.
        granularity(str, optional): The granularity of the AWS cost data for the reservation. Valid values are MONTHLY and DAILY. If GroupBy is set, Granularity can't be set. If Granularity isn't set, the response object doesn't include Granularity, either MONTHLY or DAILY. The GetReservationCoverage operation supports only DAILY and MONTHLY granularities. Defaults to None.
        filter_(Dict, optional): Filters utilization data by dimensions. You can filter by the following dimensions:   AZ   CACHE_ENGINE   DATABASE_ENGINE   DEPLOYMENT_OPTION   INSTANCE_TYPE   LINKED_ACCOUNT   OPERATING_SYSTEM   PLATFORM   REGION   SERVICE   TAG   TENANCY    GetReservationCoverage uses the same Expression object as the other operations, but only AND is supported among each dimension. You can nest only one level deep. If there are multiple values for a dimension, they are OR'd together. If you don't provide a SERVICE filter, Cost Explorer defaults to EC2. Cost category is also supported. Defaults to None.
        metrics(List, optional): The measurement that you want your reservation coverage reported in. Valid values are Hour, Unit, and Cost. You can use multiple values in a request. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.
        sort_by(Dict, optional): The value by which you want to sort the data. The following values are supported for Key:    OnDemandCost     CoverageHoursPercentage     OnDemandHours     ReservedHours     TotalRunningHours     CoverageNormalizedUnitsPercentage     OnDemandNormalizedUnits     ReservedNormalizedUnits     TotalRunningNormalizedUnits     Time    Supported values for SortOrder are ASCENDING or DESCENDING. Defaults to None.
        max_results(int, optional): The maximum number of objects that you returned for this request. If more objects are available, in the response, AWS provides a NextPageToken value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.reservation.coverage.get(ctx, time_period=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.reservation.coverage.get time_period=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_reservation_coverage",
        op_kwargs={
            "TimePeriod": time_period,
            "GroupBy": group_by,
            "Granularity": granularity,
            "Filter": filter_,
            "Metrics": metrics,
            "NextPageToken": next_page_token,
            "SortBy": sort_by,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, virtual_mfa_device_name: str, path: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new virtual MFA device for the account. After creating the virtual MFA, use EnableMFADevice to attach the MFA device to an IAM user. For more information about creating and working with virtual MFA devices, see Using a virtual MFA device in the IAM User Guide. For information about the maximum number of MFA devices you can create, see IAM and STS quotas in the IAM User Guide.  The seed information contained in the QR code and the Base32 string should be treated like any other secret access information. In other words, protect the seed information as you would your Amazon Web Services access keys or your passwords. After you provision your virtual device, you should ensure that the information is destroyed following secure procedures.

    Args:
        path(str, optional):  The path for the virtual MFA device. For more information about paths, see IAM identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        virtual_mfa_device_name(str): The name of the virtual MFA device. Use with path to uniquely identify a virtual MFA device. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List, optional): A list of tags that you want to attach to the new IAM virtual MFA device. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.virtual_mfa_device.create(
                ctx, virtual_mfa_device_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.virtual_mfa_device.create virtual_mfa_device_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_virtual_mfa_device",
        op_kwargs={
            "Path": path,
            "VirtualMFADeviceName": virtual_mfa_device_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, serial_number: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a virtual MFA device.   You must deactivate a user's virtual MFA device before you can delete it. For information about deactivating MFA devices, see DeactivateMFADevice.

    Args:
        serial_number(str): The serial number that uniquely identifies the MFA device. For virtual MFA devices, the serial number is the same as the ARN. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: =,.@:/-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.virtual_mfa_device.delete(ctx, serial_number=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.virtual_mfa_device.delete serial_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_virtual_mfa_device",
        op_kwargs={"SerialNumber": serial_number},
    )


async def list_all(
    hub, ctx, assignment_status: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the virtual MFA devices defined in the account by assignment status. If you do not specify an assignment status, the operation returns a list of all virtual MFA devices. Assignment status can be Assigned, Unassigned, or Any.  IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a virtual MFA device, see ListVirtualMFADevices.  You can paginate the results using the MaxItems and Marker parameters.

    Args:
        assignment_status(str, optional):  The status (Unassigned or Assigned) of the devices to list. If you do not specify an AssignmentStatus, the operation defaults to Any, which lists both assigned and unassigned virtual MFA devices.,. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.virtual_mfa_device.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.virtual_mfa_device.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_virtual_mfa_devices",
        op_kwargs={
            "AssignmentStatus": assignment_status,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(
    hub,
    ctx,
    load_balancer_arn: str,
    subnets: List = None,
    subnet_mappings: List = None,
    ip_address_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Enables the Availability Zones for the specified public subnets for the specified Application Load Balancer or Network Load Balancer. The specified subnets replace the previously enabled subnets. When you specify subnets for a Network Load Balancer, you must include all subnets that were enabled previously, with their existing configurations, plus any additional subnets.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.
        subnets(List, optional): The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings. [Application Load Balancers] You must specify subnets from at least two Availability Zones. [Application Load Balancers on Outposts] You must specify one Outpost subnet. [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones. [Network Load Balancers] You can specify subnets from one or more Availability Zones. Defaults to None.
        subnet_mappings(List, optional): The IDs of the public subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings. [Application Load Balancers] You must specify subnets from at least two Availability Zones. You cannot specify Elastic IP addresses for your subnets. [Application Load Balancers on Outposts] You must specify one Outpost subnet. [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones. [Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet. Defaults to None.
        ip_address_type(str, optional): [Network Load Balancers] The type of IP addresses used by the subnets for your load balancer. The possible values are ipv4 (for IPv4 addresses) and dualstack (for IPv4 and IPv6 addresses). You can’t specify dualstack for a load balancer with a UDP or TCP_UDP listener. Internal load balancers must use ipv4. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.subnet.set(ctx, load_balancer_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.subnet.set load_balancer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="set_subnets",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "Subnets": subnets,
            "SubnetMappings": subnet_mappings,
            "IpAddressType": ip_address_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, cache_security_group_name: str, description: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cache security group. Use a cache security group to control access to one or more clusters. Cache security groups are only used when you are creating a cluster outside of an Amazon Virtual Private Cloud (Amazon VPC). If you are creating a cluster inside of a VPC, use a cache subnet group instead. For more information, see CreateCacheSubnetGroup.

    Args:
        cache_security_group_name(str): A name for the cache security group. This value is stored as a lowercase string. Constraints: Must contain no more than 255 alphanumeric characters. Cannot be the word "Default". Example: mysecuritygroup .
        description(str): A description for the cache security group.
        tags(List, optional): A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.cache.security_group.init.create(
                ctx, cache_security_group_name=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.cache.security_group.init.create cache_security_group_name=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="create_cache_security_group",
        op_kwargs={
            "CacheSecurityGroupName": cache_security_group_name,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, cache_security_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a cache security group.  You cannot delete a cache security group if it is associated with any clusters.

    Args:
        cache_security_group_name(str): The name of the cache security group to delete.  You cannot delete the default security group. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.cache.security_group.init.delete(
                ctx, cache_security_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.cache.security_group.init.delete cache_security_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="delete_cache_security_group",
        op_kwargs={"CacheSecurityGroupName": cache_security_group_name},
    )


async def describe_all(
    hub,
    ctx,
    cache_security_group_name: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of cache security group descriptions. If a cache security group name is specified, the list contains only the description of that group. This applicable only when you have ElastiCache in Classic setup

    Args:
        cache_security_group_name(str, optional): The name of the cache security group to return details for. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: minimum 20; maximum 100. Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.cache.security_group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.cache.security_group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_cache_security_groups",
        op_kwargs={
            "CacheSecurityGroupName": cache_security_group_name,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub, ctx, groups: List, instance_id: str, vpc_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Links an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups. You cannot link an EC2-Classic instance to more than one VPC at a time. You can only link an instance that's in the running state. An instance is automatically unlinked from a VPC when it's stopped - you can link it to the VPC again when you restart it. After you've linked an instance, you cannot change the VPC security groups that are associated with it. To change the security groups, you must first unlink the instance, and then link it again. Linking your instance to a VPC is sometimes referred to as attaching your instance.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        groups(List): The ID of one or more of the VPC's security groups. You cannot specify security groups from a different VPC.
        instance_id(str): The ID of an EC2-Classic instance to link to the ClassicLink-enabled VPC.
        vpc_id(str): The ID of a ClassicLink-enabled VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.classic_link.vpc.attach(
                ctx, groups=value, instance_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.classic_link.vpc.attach groups=value, instance_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="attach_classic_link_vpc",
        op_kwargs={
            "DryRun": dry_run,
            "Groups": groups,
            "InstanceId": instance_id,
            "VpcId": vpc_id,
        },
    )


async def detach(hub, ctx, instance_id: str, vpc_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Unlinks (detaches) a linked EC2-Classic instance from a VPC. After the instance has been unlinked, the VPC security groups are no longer associated with it. An instance is automatically unlinked from a VPC when it's stopped.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance to unlink from the VPC.
        vpc_id(str): The ID of the VPC to which the instance is linked.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.classic_link.vpc.detach(
                ctx, instance_id=value, vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.classic_link.vpc.detach instance_id=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="detach_classic_link_vpc",
        op_kwargs={"DryRun": dry_run, "InstanceId": instance_id, "VpcId": vpc_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    vpc_id: str,
    tag_specifications: List = None,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a carrier gateway. For more information about carrier gateways, see Carrier gateways in the Amazon Web Services Wavelength Developer Guide.

    Args:
        vpc_id(str): The ID of the VPC to associate with the carrier gateway.
        tag_specifications(List, optional): The tags to associate with the carrier gateway. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.carrier_gateway.create(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.carrier_gateway.create vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_carrier_gateway",
        op_kwargs={
            "VpcId": vpc_id,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, carrier_gateway_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a carrier gateway.  If you do not delete the route that contains the carrier gateway as the Target, the route is a blackhole route. For information about how to delete a route, see DeleteRoute.

    Args:
        carrier_gateway_id(str): The ID of the carrier gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.carrier_gateway.delete(ctx, carrier_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.carrier_gateway.delete carrier_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_carrier_gateway",
        op_kwargs={"CarrierGatewayId": carrier_gateway_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    carrier_gateway_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your carrier gateways.

    Args:
        carrier_gateway_ids(List, optional): One or more carrier gateway IDs. Defaults to None.
        filters(List, optional): One or more filters.    carrier-gateway-id - The ID of the carrier gateway.    state - The state of the carrier gateway (pending | failed | available | deleting | deleted).    owner-id - The Amazon Web Services account ID of the owner of the carrier gateway.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC associated with the carrier gateway.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.carrier_gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.carrier_gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_carrier_gateways",
        op_kwargs={
            "CarrierGatewayIds": carrier_gateway_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    documentation_version: str,
    stage_name: str = None,
    description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_version(str): [Required] The version identifier of the new snapshot.
        stage_name(str, optional): The stage name to be associated with the new documentation snapshot. Defaults to None.
        description(str, optional): A description about the new documentation snapshot. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.version.create(
                ctx, rest_api_id=value, documentation_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.version.create rest_api_id=value, documentation_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_documentation_version",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationVersion": documentation_version,
            "stageName": stage_name,
            "description": description,
        },
    )


async def delete(hub, ctx, rest_api_id: str, documentation_version: str) -> None:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_version(str): [Required] The version identifier of a to-be-deleted documentation snapshot.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.version.delete(
                ctx, rest_api_id=value, documentation_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.version.delete rest_api_id=value, documentation_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_documentation_version",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationVersion": documentation_version,
        },
    )


async def get(hub, ctx, rest_api_id: str, documentation_version: str) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        documentation_version(str): [Required] The version identifier of the to-be-retrieved documentation snapshot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.version.get(
                ctx, rest_api_id=value, documentation_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.version.get rest_api_id=value, documentation_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_documentation_version",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationVersion": documentation_version,
        },
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.version.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.version.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_documentation_versions",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    documentation_version: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi..
        documentation_version(str): [Required] The version identifier of the to-be-updated documentation version.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.documentation.version.update(
                ctx, rest_api_id=value, documentation_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.documentation.version.update rest_api_id=value, documentation_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_documentation_version",
        op_kwargs={
            "restApiId": rest_api_id,
            "documentationVersion": documentation_version,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the AWS services for which the specified account is a delegated administrator. This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        account_id(str): The account ID number of a delegated administrator account in the organization.
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Organizations might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.delegated.service_for_account.list(
                ctx, account_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.delegated.service_for_account.list account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_delegated_services_for_account",
        op_kwargs={
            "AccountId": account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    targets: List,
    resource_type: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the maintenance window targets or tasks that an instance is associated with.

    Args:
        targets(List): The instance ID or key-value pair to retrieve information about.
        resource_type(str): The type of resource you want to retrieve information about. For example, INSTANCE.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.for_target.describe(
                ctx, targets=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.for_target.describe targets=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_windows_for_target",
        op_kwargs={
            "Targets": targets,
            "ResourceType": resource_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, human_task_ui_name: str, ui_template: Dict, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Defines the settings you will use for the human review workflow user interface. Reviewers will see a three-panel interface with an instruction area, the item to review, and an input area.

    Args:
        human_task_ui_name(str): The name of the user interface you are creating.
        ui_template(Dict): The Liquid template for the worker user interface.
        tags(List, optional): An array of key-value pairs that contain metadata to help you categorize and organize a human review workflow user interface. Each tag consists of a key and a value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.human_task_ui.create(
                ctx, human_task_ui_name=value, ui_template=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.human_task_ui.create human_task_ui_name=value, ui_template=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_human_task_ui",
        op_kwargs={
            "HumanTaskUiName": human_task_ui_name,
            "UiTemplate": ui_template,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, human_task_ui_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to delete a human task user interface (worker task template).  To see a list of human task user interfaces (work task templates) in your account, use . When you delete a worker task template, it no longer appears when you call ListHumanTaskUis.

    Args:
        human_task_ui_name(str): The name of the human task user interface (work task template) you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.human_task_ui.delete(ctx, human_task_ui_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.human_task_ui.delete human_task_ui_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_human_task_ui",
        op_kwargs={"HumanTaskUiName": human_task_ui_name},
    )


async def describe(hub, ctx, human_task_ui_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the requested human task user interface (worker task template).

    Args:
        human_task_ui_name(str): The name of the human task user interface (worker task template) you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.human_task_ui.describe(ctx, human_task_ui_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.human_task_ui.describe human_task_ui_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_human_task_ui",
        op_kwargs={"HumanTaskUiName": human_task_ui_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, input_device_id: str, accept: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the latest thumbnail data for the input device.

    Args:
        input_device_id(str): The unique ID of this input device. For example, hd-123456789abcdef.
        accept(str): The HTTP Accept header. Indicates the requested type for the thumbnail.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.input_.device.thumbnail.describe(
                ctx, input_device_id=value, accept=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.input_.device.thumbnail.describe input_device_id=value, accept=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="describe_input_device_thumbnail",
        op_kwargs={"InputDeviceId": input_device_id, "Accept": accept},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(hub, ctx, user_pool_id: str, username: str) -> Dict:
    r"""
    **Autogenerated function**

    Signs out users from all devices, as an administrator. It also invalidates all refresh tokens issued to a user. The user's current access and Id tokens remain valid until their expiry. Access and Id tokens expire one hour after they are issued. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID.
        username(str): The user name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.global_sign_out.admin(
                ctx, user_pool_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.global_sign_out.admin user_pool_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_user_global_sign_out",
        op_kwargs={"UserPoolId": user_pool_id, "Username": username},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    replication_task_identifier: str,
    source_endpoint_arn: str,
    target_endpoint_arn: str,
    replication_instance_arn: str,
    migration_type: str,
    table_mappings: str,
    replication_task_settings: str = None,
    cdc_start_time: str = None,
    cdc_start_position: str = None,
    cdc_stop_position: str = None,
    tags: List = None,
    task_data: str = None,
    resource_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a replication task using the specified parameters.

    Args:
        replication_task_identifier(str): An identifier for the replication task. Constraints:   Must contain 1-255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  .
        source_endpoint_arn(str): An Amazon Resource Name (ARN) that uniquely identifies the source endpoint.
        target_endpoint_arn(str): An Amazon Resource Name (ARN) that uniquely identifies the target endpoint.
        replication_instance_arn(str): The Amazon Resource Name (ARN) of a replication instance.
        migration_type(str): The migration type. Valid values: full-load | cdc | full-load-and-cdc .
        table_mappings(str): The table mappings for the task, in JSON format. For more information, see Using Table Mapping to Specify Task Settings in the Database Migration Service User Guide. .
        replication_task_settings(str, optional): Overall settings for the task, in JSON format. For more information, see Specifying Task Settings for Database Migration Service Tasks in the Database Migration Service User Guide. . Defaults to None.
        cdc_start_time(str, optional): Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error. Timestamp Example: --cdc-start-time “2018-03-08T12:12:12”. Defaults to None.
        cdc_start_position(str, optional): Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.  The value can be in date, checkpoint, or LSN/SCN format. Date Example: --cdc-start-position “2018-03-08T12:12:12” Checkpoint Example: --cdc-start-position "checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93" LSN Example: --cdc-start-position “mysql-bin-changelog.000024:373”  When you use this task setting with a source PostgreSQL database, a logical replication slot should already be created and associated with the source endpoint. You can verify this by setting the slotName extra connection attribute to the name of this logical replication slot. For more information, see Extra Connection Attributes When Using PostgreSQL as a Source for DMS. . Defaults to None.
        cdc_stop_position(str, optional): Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time. Server time example: --cdc-stop-position “server_time:2018-02-09T12:12:12” Commit time example: --cdc-stop-position “commit_time: 2018-02-09T12:12:12 “. Defaults to None.
        tags(List, optional): One or more tags to be assigned to the replication task. Defaults to None.
        task_data(str, optional): Supplemental information that the task requires to migrate the data for certain source and target endpoints. For more information, see Specifying Supplemental Data for Task Settings in the Database Migration Service User Guide. . Defaults to None.
        resource_identifier(str, optional): A friendly name for the resource identifier at the end of the EndpointArn response parameter that is returned in the created Endpoint object. The value for this parameter can have up to 31 characters. It can contain only ASCII letters, digits, and hyphen ('-'). Also, it can't end with a hyphen or contain two consecutive hyphens, and can only begin with a letter, such as Example-App-ARN1. For example, this value might result in the EndpointArn value arn:aws:dms:eu-west-1:012345678901:rep:Example-App-ARN1. If you don't specify a ResourceIdentifier value, DMS generates a default identifier value for the end of EndpointArn. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.create(
                ctx,
                replication_task_identifier=value,
                source_endpoint_arn=value,
                target_endpoint_arn=value,
                replication_instance_arn=value,
                migration_type=value,
                table_mappings=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.create replication_task_identifier=value, source_endpoint_arn=value, target_endpoint_arn=value, replication_instance_arn=value, migration_type=value, table_mappings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="create_replication_task",
        op_kwargs={
            "ReplicationTaskIdentifier": replication_task_identifier,
            "SourceEndpointArn": source_endpoint_arn,
            "TargetEndpointArn": target_endpoint_arn,
            "ReplicationInstanceArn": replication_instance_arn,
            "MigrationType": migration_type,
            "TableMappings": table_mappings,
            "ReplicationTaskSettings": replication_task_settings,
            "CdcStartTime": cdc_start_time,
            "CdcStartPosition": cdc_start_position,
            "CdcStopPosition": cdc_stop_position,
            "Tags": tags,
            "TaskData": task_data,
            "ResourceIdentifier": resource_identifier,
        },
    )


async def delete(hub, ctx, replication_task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified replication task.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the replication task to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.delete(
                ctx, replication_task_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.delete replication_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="delete_replication_task",
        op_kwargs={"ReplicationTaskArn": replication_task_arn},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
    without_settings: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about replication tasks for your account in the current region.

    Args:
        filters(List, optional): Filters applied to replication tasks. Valid filter names: replication-task-arn | replication-task-id | migration-type | endpoint-arn | replication-instance-arn. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        without_settings(bool, optional): An option to set to avoid returning information about settings. Use this to reduce overhead when setting information is too large. To use this option, choose true; otherwise, choose false (the default). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="describe_replication_tasks",
        op_kwargs={
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
            "WithoutSettings": without_settings,
        },
    )


async def modify(
    hub,
    ctx,
    replication_task_arn: str,
    replication_task_identifier: str = None,
    migration_type: str = None,
    table_mappings: str = None,
    replication_task_settings: str = None,
    cdc_start_time: str = None,
    cdc_start_position: str = None,
    cdc_stop_position: str = None,
    task_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified replication task. You can't modify the task endpoints. The task must be stopped before you can modify it.  For more information about DMS tasks, see Working with Migration Tasks in the Database Migration Service User Guide.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the replication task.
        replication_task_identifier(str, optional): The replication task identifier. Constraints:   Must contain 1-255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  . Defaults to None.
        migration_type(str, optional): The migration type. Valid values: full-load | cdc | full-load-and-cdc . Defaults to None.
        table_mappings(str, optional): When using the CLI or boto3, provide the path of the JSON file that contains the table mappings. Precede the path with file://. For example, --table-mappings file://mappingfile.json. When working with the DMS API, provide the JSON as the parameter value. . Defaults to None.
        replication_task_settings(str, optional): JSON file that contains settings for the task, such as task metadata settings. Defaults to None.
        cdc_start_time(str, optional): Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error. Timestamp Example: --cdc-start-time “2018-03-08T12:12:12”. Defaults to None.
        cdc_start_position(str, optional): Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.  The value can be in date, checkpoint, or LSN/SCN format. Date Example: --cdc-start-position “2018-03-08T12:12:12” Checkpoint Example: --cdc-start-position "checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93" LSN Example: --cdc-start-position “mysql-bin-changelog.000024:373”  When you use this task setting with a source PostgreSQL database, a logical replication slot should already be created and associated with the source endpoint. You can verify this by setting the slotName extra connection attribute to the name of this logical replication slot. For more information, see Extra Connection Attributes When Using PostgreSQL as a Source for DMS. . Defaults to None.
        cdc_stop_position(str, optional): Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time. Server time example: --cdc-stop-position “server_time:2018-02-09T12:12:12” Commit time example: --cdc-stop-position “commit_time: 2018-02-09T12:12:12 “. Defaults to None.
        task_data(str, optional): Supplemental information that the task requires to migrate the data for certain source and target endpoints. For more information, see Specifying Supplemental Data for Task Settings in the Database Migration Service User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.modify(
                ctx, replication_task_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.modify replication_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="modify_replication_task",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "ReplicationTaskIdentifier": replication_task_identifier,
            "MigrationType": migration_type,
            "TableMappings": table_mappings,
            "ReplicationTaskSettings": replication_task_settings,
            "CdcStartTime": cdc_start_time,
            "CdcStartPosition": cdc_start_position,
            "CdcStopPosition": cdc_stop_position,
            "TaskData": task_data,
        },
    )


async def move(
    hub, ctx, replication_task_arn: str, target_replication_instance_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Moves a replication task from its current replication instance to a different target replication instance using the specified parameters. The target replication instance must be created with the same or later DMS version as the current replication instance.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the task that you want to move.
        target_replication_instance_arn(str): The ARN of the replication instance where you want to move the task to.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.move(
                ctx, replication_task_arn=value, target_replication_instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.move replication_task_arn=value, target_replication_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="move_replication_task",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "TargetReplicationInstanceArn": target_replication_instance_arn,
        },
    )


async def start(
    hub,
    ctx,
    replication_task_arn: str,
    start_replication_task_type: str,
    cdc_start_time: str = None,
    cdc_start_position: str = None,
    cdc_stop_position: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the replication task. For more information about DMS tasks, see Working with Migration Tasks  in the Database Migration Service User Guide.

    Args:
        replication_task_arn(str): The Amazon Resource Name (ARN) of the replication task to be started.
        start_replication_task_type(str): A type of replication task.
        cdc_start_time(str, optional): Indicates the start time for a change data capture (CDC) operation. Use either CdcStartTime or CdcStartPosition to specify when you want a CDC operation to start. Specifying both values results in an error. Timestamp Example: --cdc-start-time “2018-03-08T12:12:12”. Defaults to None.
        cdc_start_position(str, optional): Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want a CDC operation to start. Specifying both values results in an error.  The value can be in date, checkpoint, or LSN/SCN format. Date Example: --cdc-start-position “2018-03-08T12:12:12” Checkpoint Example: --cdc-start-position "checkpoint:V1#27#mysql-bin-changelog.157832:1975:-1:2002:677883278264080:mysql-bin-changelog.157832:1876#0#0#*#0#93" LSN Example: --cdc-start-position “mysql-bin-changelog.000024:373”  When you use this task setting with a source PostgreSQL database, a logical replication slot should already be created and associated with the source endpoint. You can verify this by setting the slotName extra connection attribute to the name of this logical replication slot. For more information, see Extra Connection Attributes When Using PostgreSQL as a Source for DMS. . Defaults to None.
        cdc_stop_position(str, optional): Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time. Server time example: --cdc-stop-position “server_time:2018-02-09T12:12:12” Commit time example: --cdc-stop-position “commit_time: 2018-02-09T12:12:12 “. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.start(
                ctx, replication_task_arn=value, start_replication_task_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.start replication_task_arn=value, start_replication_task_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="start_replication_task",
        op_kwargs={
            "ReplicationTaskArn": replication_task_arn,
            "StartReplicationTaskType": start_replication_task_type,
            "CdcStartTime": cdc_start_time,
            "CdcStartPosition": cdc_start_position,
            "CdcStopPosition": cdc_stop_position,
        },
    )


async def stop(hub, ctx, replication_task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops the replication task.

    Args:
        replication_task_arn(str): The Amazon Resource Name(ARN) of the replication task to be stopped.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dms.replication.task.init.stop(ctx, replication_task_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dms.replication.task.init.stop replication_task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dms",
        operation="stop_replication_task",
        op_kwargs={"ReplicationTaskArn": replication_task_arn},
    )
